@@ -1,10 +1,4 @@
 import os
-
-if os.name == "nt":
-    script_directory = os.path.dirname(os.path.realpath(__file__))
-    os.environ["PATH"] = script_directory + os.pathsep + os.environ["PATH"]
-
-import mpv
 import sys
 import time
 import hpcomt
@@ -82,9 +76,6 @@ def scegliEpisodi() -> tuple[int, int]:
     if anime.ep == 1:
         return 1, 1
 
-    if lista:
-        return anime.ep, anime.ep
-
     # faccio decire all'utente il range di ep
     if (nome_os == "Android"):
         my_print("Attenzione! Su Android non è ancora possibile specificare un range per lo streaming", color="giallo")
@@ -207,6 +198,8 @@ def openMPV(url_server: str, nome_video: str):
         # apro il player utilizzando bash e riproduco un video
         os.system(f'''am start --user 0 -a android.intent.action.VIEW -d "{url_server}" -n is.xyz.mpv/.MPVActivity > /dev/null 2>&1 &''')
     else:
+        import mpv
+        
         player = mpv.MPV(input_default_bindings=True,input_vo_keyboard=True, osc=True)
 
         # avvio il player
@@ -240,7 +233,8 @@ def openVLC(url_server: str, nome_video: str):
 
 def addToCronologia(ep: int):
     """
-    Viene aggiunta alla cronologia locale il nome del video
+    Viene aggiunta alla cronologia locale il nome del video,
+    il numero dell'ultimo episodio visualizzato
     e il link di AnimeWorld relativo all'anime.
     La cronologia viene salvata su un file csv nella stessa 
     directory dello script. Se il file non esiste viene creato.
@@ -250,16 +244,26 @@ def addToCronologia(ep: int):
     """
     for i, riga in enumerate(log):
         #se l'anime è presente
-        if riga[2] == anime.url:
+        if riga[0] == anime.name:
             #se l'ep riprodotto è l'ultimo allora non lo inserisco più
             if ep == anime.ep and anime.status == 1:
                 log.pop(i)
             else: 
                 #sovrascrivo la riga   
                 log[i][1] = ep
+                temp = log.pop(i)
+                #se l'anime è in corso e l'ep visualizzato è l'ultimo, metto l'anime alla fine della cronologia
+                if anime.status == 0 and ep == anime.ep:
+                    log.insert(len(log), temp)
+                #altrimenti all'inizio
+                else:
+                    log.insert(0, temp)
             return
     if (ep == anime.ep and anime.status == 0) or ep != anime.ep:
-        log.append([anime.name, ep, anime.url]) 
+        if anime.status == 0 and ep == anime.ep:
+            log.insert(len(log), [anime.name, ep, anime.url])
+        else:
+            log.insert(0, [anime.name, ep, anime.url]) 
 
 
 def openVideos(ep_iniziale: int, ep_finale: int, mpv: bool):
@@ -364,7 +368,7 @@ def main():
             syncpl = True
     if args.download:
         downl = True
-    elif args.lista:
+    if args.lista:
         lista = True
     elif args.offline:
         offline = True
@@ -373,101 +377,128 @@ def main():
 
     mpv = getConfig()
 
-    try:
-        if not cronologia:
-            animelist = latest(args.lista) if lista else animeScaricati(downloadPath()) if offline else RicercaAnime()
-        else:
-            animelist, episodi = getCronologia()
-
-        while True:
-            my_print("", end="", cls=True)
-            # stampo i nomi degli anime
-            for i, a in reversed(list(enumerate(animelist))):
-                my_print(f"{i + 1} ", color="verde", end=" ")
-                if lista or cronologia:
-                    my_print(f"{a.name} [Ep {a.ep}]")
-                else:
-                    my_print(a.name)
-
-            def check_index(s: str):
-                if s.isdigit():
-                    index = int(s) - 1
-                    if index in range(len(animelist)):
-                        return index
-            
-            scelta = my_input("Scegli un anime", check_index)
-            anime = animelist[scelta]
-
-            anime.load_episodes() if not offline else anime.downloaded_episodes(f"{downloadPath()}/{anime.name}")
-
-            if anime.ep != 0:
-                break
-
-            # se l'anime non ha episodi non può essere selezionato
-            my_print("Eh, volevi! L'anime non ha episodi", color="rosso")
-            time.sleep(1)
-
-        if not cronologia:
-            ep_iniziale, ep_finale = scegliEpisodi()
-        else:
-            ep_iniziale = int(episodi[scelta]) + 1
-            ep_finale = ep_iniziale
-            if ep_finale > anime.ep:
-                my_print(f"L'episodio {ep_iniziale} di {anime.name} non è ancora stato rilasciato!", color='rosso')
-                exit()
-        # se syncplay è stato scelto allora non chiedo
-        # di fare il download ed esco dalla funzione
-        if not syncpl and downl:
-            path = f"{downloadPath()}/{anime.name}"
-            for ep in range(ep_iniziale, ep_finale+1):
-                scaricaEpisodio(ep, path)
-
-            my_print("Tutti i video scaricati correttamente!\nLi puoi trovare nella cartella", color="verde", end=" ")
-            if nome_os == "Android":
-                my_print("Movies/Anime", color="verde")
+    while True:
+        try:
+            if not cronologia:
+                animelist = latest(args.lista) if lista else animeScaricati(downloadPath()) if offline else RicercaAnime()
             else:
-                my_print("Video/Anime", color="verde")
-                
-                #chiedi all'utente se aprire ora i video scaricati
-                if my_input("Aprire ora il player con gli episodi scaricati? (S/n)", lambda i: i.lower()) in ['s', '']:
-                    openVideos(ep_iniziale, ep_finale, mpv)
-            safeExit()
+                animelist, episodi = getCronologia()
 
-        ris_valida = True
-        while True:
-            if ris_valida:
-                openVideos(ep_iniziale,ep_finale, mpv)
-            else:
-                my_print("Seleziona una risposta valida", color="rosso")
-                ris_valida = True
-            # menù che si visualizza dopo aver finito la riproduzione
-            my_print("(p) prossimo", color="azzurro")
-            my_print("(r) riguarda", color="blu")
-            my_print("(a) antecedente", color="azzurro")
-            my_print("(s) seleziona", color="verde")
-            my_print("(e) esci", color="rosso")
-            my_print(">", color="magenta", end=" ")
-            scelta_menu = input().lower()
-            if (scelta_menu == 'p' or scelta_menu == '') and ep_iniziale < anime.ep - (ep_finale - ep_iniziale):
-                ep_iniziale = ep_finale + 1
-                ep_finale = ep_iniziale
-                continue
-            elif scelta_menu == 'r':
-                continue            
-            elif scelta_menu == 'a' and ep_finale > anime.ep_ini:
-                ep_iniziale = ep_finale - 1
-                ep_finale = ep_iniziale
-                continue
-            elif scelta_menu == 's':
-                ep_iniziale, ep_finale = scegliEpisodi()
-            elif scelta_menu == 'e':
-                safeExit()
-            else:
+            while True:
                 my_print("", end="", cls=True)
-                ris_valida = False
+                # stampo i nomi degli anime
+                for i, a in reversed(list(enumerate(animelist))):
+                    my_print(f"{i + 1} ", color="verde", end=" ")
+                    if lista or cronologia:
+                        my_print(f"{a.name} [Ep {a.ep}]")
+                    else:
+                        my_print(a.name)
 
-    except KeyboardInterrupt:
-        safeExit()
+                def check_index(s: str):
+                    if s.isdigit():
+                        index = int(s) - 1
+                        if index in range(len(animelist)):
+                            return index
+                
+                scelta = my_input("Scegli un anime", check_index)
+                anime = animelist[scelta]
+                #se la lista è stata selezionata, inserisco come ep_iniziale e ep_finale quello scelto dall'utente
+                #succcessivamente anime.ep verrà sovrascritto con il numero reale dell'episodio finale
+                if lista:
+                    ep_iniziale = anime.ep
+                    ep_finale = ep_iniziale
+                anime.load_episodes() if not offline else anime.downloaded_episodes(f"{downloadPath()}/{anime.name}")
+
+                if anime.ep != 0:
+                    break
+
+                # se l'anime non ha episodi non può essere selezionato
+                my_print("Eh, volevi! L'anime non è ancora stato rilasciato", color="rosso")
+                time.sleep(1)
+
+            if not cronologia:
+                if not lista:
+                    ep_iniziale, ep_finale = scegliEpisodi()
+            else:
+                ep_iniziale = int(episodi[scelta]) + 1
+                ep_finale = ep_iniziale
+                if ep_finale > anime.ep:
+                    my_print(f"L'episodio {ep_iniziale} di {anime.name} non è ancora stato rilasciato!", color='rosso')
+                    if len(log) == 1:
+                        exit()
+                    else:
+                        sleep(1)
+                        continue
+            # se syncplay è stato scelto allora non chiedo
+            # di fare il download ed esco dalla funzione
+            if not syncpl and downl:
+                path = f"{downloadPath()}/{anime.name}"
+                for ep in range(ep_iniziale, ep_finale+1):
+                    scaricaEpisodio(ep, path)
+
+                my_print("Tutti i video scaricati correttamente!\nLi puoi trovare nella cartella", color="verde", end=" ")
+                if nome_os == "Android":
+                    my_print("Movies/Anime", color="verde")
+                else:
+                    my_print("Video/Anime", color="verde")
+                    
+                    #chiedi all'utente se aprire ora i video scaricati
+                    if my_input("Aprire ora il player con gli episodi scaricati? (S/n)", lambda i: i.lower()) in ['s', '']:
+                        openVideos(ep_iniziale, ep_finale, mpv)
+                safeExit()
+
+            ris_valida = True
+            while True:
+                if ris_valida:
+                    openVideos(ep_iniziale,ep_finale, mpv)
+                else:
+                    my_print("Seleziona una risposta valida", color="rosso")
+                    ris_valida = True
+
+                prossimo = True
+                antecedente = True
+                seleziona = True
+
+                # menù che si visualizza dopo aver finito la riproduzione
+                if ep_finale != anime.ep:
+                    my_print("(p) prossimo", color="azzurro")
+                else:
+                    prossimo = False
+                my_print("(r) riguarda", color="blu")
+                if ep_finale != anime.ep_ini:
+                    my_print("(a) antecedente", color="azzurro")
+                else:
+                    antecedente = False
+                if anime.ep != 1:
+                    my_print("(s) seleziona", color="verde")
+                else:
+                    seleziona = False
+                my_print("(i) indietro", color='magenta')
+                my_print("(e) esci", color="rosso")
+                my_print(">", color="magenta", end=" ")
+                scelta_menu = input().lower()
+                if (scelta_menu == 'p' or scelta_menu == '') and prossimo:
+                    ep_iniziale = ep_finale + 1
+                    ep_finale = ep_iniziale
+                    continue
+                elif scelta_menu == 'r':
+                    continue            
+                elif scelta_menu == 'a' and antecedente:
+                    ep_iniziale = ep_finale - 1
+                    ep_finale = ep_iniziale
+                    continue
+                elif scelta_menu == 's' and seleziona:
+                    ep_iniziale, ep_finale = scegliEpisodi()
+                elif scelta_menu == 'i':
+                    break
+                elif scelta_menu == 'e':
+                    safeExit()
+                else:
+                    my_print("", end="", cls=True)
+                    ris_valida = False
+
+        except KeyboardInterrupt:
+            safeExit()
 
 # controllo il tipo del dispositivo
 nome_os = hpcomt.Name()
